/* #################### MENUBAR ################### */

.menubar,
.menubar *
{
  color : #000000;

  padding : 1px 2px;
  background-image  : url("Menu-Menubar/menubar.png");
  background-size: cover;

  border-width      : 1px;
}

.menubar:hover,
.menubar:active,
.menubar:hover *,
.menubar:active *
{
  color : #404040;
}

.menubar:disabled,
.menubar:disabled *
{
  color : #b2b2b2;
}

.menuitem:hover
{
  background-image  : url("Menu-Menubar/menubar-item.png");
  background-size: cover;
  background-color : #b6a785;
  border-width      : 0px;
}
